@@ -24,7 +24,6 @@ replace()
 """
 import warnings
 import numpy as np
-import sympy as sp
 from itertools import chain
 
 standardColorsHex = ['#5B84B1FF', '#FC766AFF', '#5F4B8BFF', '#E69A8DFF', '#42EADDFF', '#CDB599FF', '#00A4CCFF',
@@ -32,6 +31,8 @@ standardColorsHex = ['#5B84B1FF', '#FC766AFF', '#5F4B8BFF', '#E69A8DFF', '#42EAD
                      '#2C5F2D', '#97BC62FF', '#00539CFF', '#EEA47FFF', '#D198C5FF', '#E0C568FF']
 alphabetSequence = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n',
                     'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z']
+alphabetSequenceCap = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S',
+                       'T', 'U', 'V', 'W', 'X', 'Y', 'Z']
 
 
 def string_to_float(potential_float):
@@ -152,23 +153,23 @@ def nest_checker(element, otype='list'):
 
     # check whether element is a string. If true, pack into list, if false try iterate
     if isinstance(element, str):
-        resElem = [element]
+        res_elem = [element]
     else:
         try:
-            resElem = [i for i in element]
+            res_elem = [i for i in element]
         except AttributeError:  # if iteration fails (not a packaged type element), pack into list
-            resElem = [element]
+            res_elem = [element]
 
     # convert the list into the desired output type
     if otype == 'list':
-        resNest = resElem
+        res_nest = res_elem
     elif otype == 'tuple':
-        resNest = tuple(resElem)
+        res_nest = tuple(res_elem)
     elif otype == 'ndarray':
-        resNest = np.array(resElem)
+        res_nest = np.array(res_elem)
     else:
         raise ValueError(f'Output type \'{otype}\' is not supported.')
-    return resNest
+    return res_nest
 
 
 def elem_checker(elems, lists, flat=False, overwrite=False):
@@ -190,7 +191,7 @@ def elem_checker(elems, lists, flat=False, overwrite=False):
             The default is False.
 
     Returns
-        List of all elements found in the passed lists, along with the indexes in the respective passed lists.
+        List of all elements found in the provided lists, along with the indexes in the respective passed lists.
     """
 
     value_list = []
@@ -244,7 +245,12 @@ def float_to_int(float_element, fail_action='pass'):
         float_element = float(float_element)
 
     float_string = str(float_element)
-    float_decimals = float_string[float_string.index('.'):]
+    try:  # try to find the decimal dot in the float
+        float_decimals = float_string[float_string.index('.'):]
+    except ValueError:  # this should only fail, if the float_element is in scientific notation, with no decimals
+        # this will then fail, as float_element is then a float without a decimal
+        # upon this exception, float_element cannot be converted to an int, so the function stops and returns initial.
+        return float_element
 
     # if all decimals are zero, then set the given float as an int
     if all(i == '0' for i in float_decimals[1:]):
@@ -254,28 +260,34 @@ def float_to_int(float_element, fail_action='pass'):
             res = float_element
         elif fail_action == 'error':  # if fail action is 'error', then raise a TypeError
             raise TypeError(f'Float \'{float_element}\' cannot be converted to int.')
+        else:
+            raise ValueError(f'There is no such fail action, \'{fail_action}\'.')
     return res
 
 
-def replace(elem, rep, string):
+def replace(elems, reps, string):
     """
-    Replaces the element inside the string, if the element is inside the string. Can replace sequences up to 9
-    elements.
+    Replaces the element(s) inside the string, if the element(s) is(are) inside the string. Can replace sequences up to
+    10 letters.
 
     Parameters
-        elem : str
-            The element to be replaced.
-        rep : str
-            The element to replace with.
+        elem : str or tuple
+            The element(s) to be replaced. If tuple, replaces those elements in the tuple.
+        rep : str or tuple
+            The element(s) to replace with.
         string : str
             The string in which an element is to be replaced.
 
     Returns
-        New string with the replaced element.
+        New string with the replaced element(s).
     """
 
+    # make sure that elems and reps are indeed tuples
+    elems = nest_checker(elems, 'tuple')
+    reps = nest_checker(reps, 'tuple')
+
     pre_float_string = [i for i in string]  # decompose input string into elements in a list
-    decom_elem = [i for i in elem]  # decompose rep string
+    decom_elems = [[i for i in j] for j in elems]  # decompose rep string
 
     i = 0  # define initial
     temp_string = pre_float_string
@@ -305,10 +317,10 @@ def replace(elem, rep, string):
         # define a packed index
         packed_values = [i0_val, ip1_val, ip2_val, ip3_val, ip4_val, ip5_val, ip6_val, ip7_val, ip8_val, ip9_val]
 
-        if decom_elem == packed_values[:len(decom_elem)]:
-            temp_string = [rep if k == i else j for k, j in indexer(string) if k not in
-                           packed_indexes[:len(decom_elem) - 1]]
-            continue  # break and restart loop with the updated list
+        for es, o in zip(decom_elems, reps):
+            if es == packed_values[:len(es)]:
+                temp_string = [o if k == i else j for k, j in indexer(temp_string) if k not in
+                               packed_indexes[:len(es) - 1]]
         i += 1  # update iterative
     res = list_to_string(temp_string)  # define result and convert to string
     return res
